pub enum ClearNet {}Trait Implementations
impl Copy for ClearNet
Sourceimpl NetworkZone for ClearNet
impl NetworkZone for ClearNet
Sourceconst CHECK_NODE_ID: bool = true
const CHECK_NODE_ID: bool = true
Check if our node ID matches the incoming peers node ID for this network. Read more
Sourceconst BROADCAST_OWN_ADDR: bool = false
const BROADCAST_OWN_ADDR: bool = false
If
true, this network zone requires us to blend our own address and port into
the address book we plan on sharing to other peers.Sourcetype Addr = SocketAddr
type Addr = SocketAddr
The address type of this network.