Struct CoreSyncData
pub struct CoreSyncData {
pub cumulative_difficulty: u64,
pub cumulative_difficulty_top64: u64,
pub current_height: u64,
pub pruning_seed: u32,
pub top_id: [u8; 32],
pub top_version: u8,
}Expand description
Core Sync Data, information on the sync state of a peer
Fields
cumulative_difficulty: u64Cumulative Difficulty Low The lower 64 bits of the 128 bit cumulative difficulty
cumulative_difficulty_top64: u64Cumulative Difficulty High The upper 64 bits of the 128 bit cumulative difficulty
current_height: u64Current Height of the peer
pruning_seed: u32Pruning Seed of the peer (If this is not in the message the default is 0)
top_id: [u8; 32]Hash of the top block
top_version: u8Version of the top block
Implementations
impl CoreSyncData
impl CoreSyncData
pub const fn new( cumulative_difficulty_128: u128, current_height: u64, pruning_seed: u32, top_id: [u8; 32], top_version: u8, ) -> CoreSyncData
pub fn cumulative_difficulty(&self) -> u128
pub fn cumulative_difficulty(&self) -> u128
Returns the 128 bit cumulative difficulty of the peers blockchain